pub type LotteryTargetValue = BaseFieldElement;Expand description
Target value type used in the lottery for snark proof system
Aliased Type
pub struct LotteryTargetValue(/* private fields */);pub type LotteryTargetValue = BaseFieldElement;Target value type used in the lottery for snark proof system
pub struct LotteryTargetValue(/* private fields */);