pub struct MidnightPoseidonDigest { /* private fields */ }Expand description
Wrapper to implement the Digest trait for the Poseidon hash function We need this implementation to keep the merkle tree implementation generic over the Digest used.
This implementation differs from the usual behavior of the digest update as documented in the update implementation.
Implementations